@@ -39,8 +39,14 @@ void compare_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cp
 	command_from = alloca(REPLACE_LEN);
 	command_to = alloca(REPLACE_LEN);
 
-	memset(pipe_buf_from, 0, PATH_MAX);
-	memset(pipe_buf_to, 0, PATH_MAX);
+	/*
+	 * 以下のコードだとメモリ破壊（cpinfo->toの破壊）を起こしていた。
+	 * memset(pipe_buf_from, 0, PATH_MAX);
+	 * memset(pipe_buf_to, 0, PATH_MAX);
+	*/
+
+	pipe_buf_from[0] = '\0';
+	pipe_buf_to[0] = '\0';
 
 	strcpy(re_from, cpinfo->from);
 	strcpy(re_to, cpinfo->to);
