@@ -27,28 +27,21 @@
 #define TO_OPEN \
 {\
 	errno = 0;\
-	if((ito = open(cpinfo->to, O_CREAT | O_NOFOLLOW | O_WRONLY, S_IRUSR | S_IWUSR)) == -1)\
+	if((ito = open(cpinfo->to, O_CREAT | O_NOATIME | O_NOFOLLOW | O_WRONLY, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH)) == -1)\
 	{\
 		switch(errno)\
 		{\
-		case ELOOP:\
+		case EPERM:\
 			errno = 0;\
 \
-			if(unlink(cpinfo->to) == -1)\
+			if((ito = open(cpinfo->to, O_CREAT | O_NOFOLLOW | O_WRONLY, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH)) == -1)\
 			{\
-				print_error("unlink", __FILE__, __LINE__, cpdd);\
+				print_error("open", __FILE__, __LINE__, cpdd);\
 			}\
 			else \
 			{\
-				if((ito = open(cpinfo->to, O_CREAT | O_NOFOLLOW | O_WRONLY, S_IRUSR | S_IWUSR)) == -1)\
-				{\
-					print_error("open", __FILE__, __LINE__, cpdd);\
-				}\
-				else \
-				{\
-					to_open = true;\
-					cpdd->mk_file_count++;\
-				}\
+				to_open = true;\
+				cpdd->mk_file_count++;\
 			}\
 			break;\
 \
@@ -142,14 +135,35 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 	write_now = cpinfo->to;
 
 	errno = 0;
-	if((ifrom = open(cpinfo->from, O_RDONLY | O_NOATIME)) == -1)
+	if((ifrom = open(cpinfo->from, O_RDONLY | O_NOATIME | O_NOFOLLOW)) == -1)
 	{
-		print_error("open", __FILE__, __LINE__, cpdd);
+		switch(errno)
+		{
+		case EPERM:
+			errno = 0;
+
+			if((ifrom = open(cpinfo->from, O_RDONLY | O_NOFOLLOW)) == -1)
+			{
+				print_error("open", __FILE__, __LINE__, cpdd);
+			}
+			else
+			{
+				from_open = true;
+			}
+			break;
+
+		default:
+			print_error("open", __FILE__, __LINE__, cpdd);
+			break;
+		}
 	}
 	else
 	{
 		from_open = true;
+	}
 
+	if(from_open == true)
+	{
 		errno = 0;
 		if(fstat(ifrom, &stat_buf) == -1)
 		{
