@@ -35,15 +35,28 @@ int main(int argc, char **argv)
 
 	SDir *sdir = get_settings_dir();
 
-	// 引数が1つで、-oの場合、オプションを設定、保存し、終了する。
 	if(argc == 2)
 	{
 		char *tmp = argv[1];
+
+		// -oの場合、オプションを設定、保存し、終了する。
 		if((tmp[0] == '-') && (tmp[1] == 'o'))
 		{
 			write_conf(sdir);
 			return EXIT_SUCCESS;
 		}
+		// -hの場合はヘルプを表示する
+		else if((tmp[0] == '-') && (tmp[1] == 'h'))
+		{
+			help();
+			return EXIT_SUCCESS;
+		}
+		// --helpの場合もヘルプを表示する
+		else if((tmp[0] == '-') && (tmp[1] == '-') && (tmp[2] == 'h') && (tmp[3] == 'e') && (tmp[4] == 'l') && (tmp[5] == 'p'))
+		{
+			help();
+			return EXIT_SUCCESS;
+		}
 	}
 
 	OPArg *oparg = read_conf(sdir);
