@@ -33,13 +33,16 @@ void write_conf(const SDir *sdir)
 
 	char stdin_buf[INPUT_LEN];
 	char compare = '@';
-	char compare_mode = '@';
+	char COMPARE_MODE = '@';
 	int b_op = 0;
 	char i_op = '@';
 	char l_op = '@';
+	char m_op = '@';
+	char t_op = '@';
+	char THREAD_MODE = '@';
 	char v_op = '@';
 	char w_op = '@';
-	char write_mode = '@';
+	char WRITE_MODE = '@';
 
 	puts("設定の変更を行います");
 
@@ -74,7 +77,7 @@ void write_conf(const SDir *sdir)
 
 				if((stdin_buf[0] == '1') || (stdin_buf[0] == '2'))
 				{
-					compare_mode = stdin_buf[0];
+					COMPARE_MODE = stdin_buf[0];
 				}
 			}
 
@@ -153,12 +156,52 @@ void write_conf(const SDir *sdir)
 
 				if((stdin_buf[0] == '1') || (stdin_buf[0] == '2') || (stdin_buf[0] == '3') || (stdin_buf[0] == '0'))
 				{
-					write_mode = stdin_buf[0];
+					WRITE_MODE = stdin_buf[0];
 				}
 			}
 		}
 	}
 
+	{
+		puts("");
+		puts("移動モード (ファイルコピー後、元ファイルを削除) に設定しますか?");
+		printf("(y / n) :");
+
+		INPUT_CHECK_CLEAN
+
+		if(stdin_buf[0] == 'y')
+		{
+			m_op = stdin_buf[0];
+		}
+	}
+
+	{
+		puts("");
+		puts("スレッドモードを指定しますか?");
+		printf("(y / n) :");
+
+		INPUT_CHECK_CLEAN
+
+		if(stdin_buf[0] == 'y')
+		{
+			t_op = stdin_buf[0];
+
+			puts("");
+			puts("モードを選んでください (初期設定は自動判別)");
+			puts("1 : 常に同一ドライブモード");
+			puts("2 : 常に別ドライブモード");
+			puts("0 : 初期設定");
+			printf("(1 / 2 / 0) :");
+
+			INPUT_CHECK_CLEAN
+
+			if((stdin_buf[0] == '1') || (stdin_buf[0] == '2') || (stdin_buf[0] == '0'))
+			{
+				THREAD_MODE = stdin_buf[0];
+			}
+		}
+	}
+
 	{
 		puts("");
 		puts("コピー中のファイル名を表示しますか?");
@@ -174,10 +217,10 @@ void write_conf(const SDir *sdir)
 
 	// 設定をファイルに保存する
 	if(
-		(compare_mode != '@') ||
+		(COMPARE_MODE != '@') ||
 		(b_op > 0) ||
 		(i_op != '@') ||
-		(write_mode != '@') ||
+		(WRITE_MODE != '@') ||
 		(v_op != '@')
 	)
 	{
@@ -222,7 +265,7 @@ void write_conf(const SDir *sdir)
 
 			puts(" ");
 
-			if(compare_mode != '@')
+			if(COMPARE_MODE != '@')
 			{
 				{
 					if(fputc(compare, config) == EOF)
@@ -233,7 +276,7 @@ void write_conf(const SDir *sdir)
 					{
 						write_error("fputs");
 					}
-					else if(fputc(compare_mode, config) == EOF)
+					else if(fputc(COMPARE_MODE, config) == EOF)
 					{
 						write_error("fputc");
 					}
@@ -256,7 +299,7 @@ void write_conf(const SDir *sdir)
 					puts("コンペアタイプ : memcmp");
 				}
 
-				printf("コンペアモード : %c\n", compare_mode);
+				printf("コンペアモード : %c\n", COMPARE_MODE);
 			}
 
 			if(b_op > 0)
@@ -292,7 +335,7 @@ void write_conf(const SDir *sdir)
 				puts("上書き確認する");
 			}
 
-			if(write_mode != '@')
+			if(WRITE_MODE != '@')
 			{
 				{
 					if(fputs("w", config) == EOF)
@@ -303,7 +346,7 @@ void write_conf(const SDir *sdir)
 					{
 						write_error("fputs");
 					}
-					else if(fputc(write_mode, config) == EOF)
+					else if(fputc(WRITE_MODE, config) == EOF)
 					{
 						write_error("fputc");
 					}
@@ -313,7 +356,7 @@ void write_conf(const SDir *sdir)
 					}
 				}
 
-				printf("上書きモード   : %c\n", write_mode);
+				printf("上書きモード   : %c\n", WRITE_MODE);
 			}
 
 			if(l_op != '@')
@@ -331,6 +374,45 @@ void write_conf(const SDir *sdir)
 				puts("コンペアログを保存する");
 			}
 
+			if(m_op != '@')
+			{
+				if(
+					(fputs("m", config) == EOF) ||
+					(fputs(",", config) == EOF) ||
+					(fputs("NULL", config) == EOF) ||
+					(fputs("\n", config) == EOF)
+				)
+				{
+					write_error("fputs");
+				}
+
+				puts("移動モード");
+			}
+
+			if(THREAD_MODE != '@')
+			{
+				{
+					if(fputs("t", config) == EOF)
+					{
+						write_error("fputc");
+					}
+					else if(fputs(",", config) == EOF)
+					{
+						write_error("fputs");
+					}
+					else if(fputc(THREAD_MODE, config) == EOF)
+					{
+						write_error("fputc");
+					}
+					else if(fputs("\n", config) == EOF)
+					{
+						write_error("fputs");
+					}
+				}
+
+				printf("スレッドモード : %c\n", THREAD_MODE);
+			}
+
 			if(v_op != '@')
 			{
 				if(
